@@ -268,7 +268,7 @@ class Cog(metaclass=CogMeta):
     __cog_listeners__: List[Tuple[str, str]]
     __cog_is_app_commands_group__: ClassVar[bool] = False
     __cog_app_commands_group__: Optional[app_commands.Group]
-    __app_commands_error_handler__: Optional[
+    __discord_app_commands_error_handler__: Optional[
         Callable[[discord.Interaction, app_commands.AppCommandError], Coroutine[Any, Any, None]]
     ]
 
@@ -328,6 +328,13 @@ class Cog(metaclass=CogMeta):
                     if self.__cog_app_commands_group__:
                         children.append(app_command)
 
+        if Cog._get_overridden_method(self.cog_app_command_error) is not None:
+            error_handler = self.cog_app_command_error
+        else:
+            error_handler = None
+
+        self.__discord_app_commands_error_handler__ = error_handler
+
         for command in cls.__cog_app_commands__:
             copy = command._copy_with(parent=self.__cog_app_commands_group__, binding=self)
 
@@ -335,6 +342,12 @@ class Cog(metaclass=CogMeta):
             if copy._attr:
                 setattr(self, copy._attr, copy)
 
+            if isinstance(copy, app_commands.Group):
+                copy.__discord_app_commands_error_handler__ = error_handler
+                for command in copy._children.values():
+                    if isinstance(command, app_commands.Group):
+                        command.__discord_app_commands_error_handler__ = error_handler
+
             children.append(copy)
 
         self.__cog_app_commands__ = children
@@ -346,11 +359,6 @@ class Cog(metaclass=CogMeta):
 
             self.__cog_app_commands_group__._children = mapping  # type: ignore  # Variance issue
 
-        if Cog._get_overridden_method(self.cog_app_command_error) is not None:
-            self.__app_commands_error_handler__ = self.cog_app_command_error
-        else:
-            self.__app_commands_error_handler__ = None
-
         return self
 
     def get_commands(self) -> List[Command[Self, ..., Any]]:
@@ -616,7 +624,10 @@ class Cog(metaclass=CogMeta):
                     for to_undo in self.__cog_commands__[:index]:
                         if to_undo.parent is None:
                             bot.remove_command(to_undo.name)
-                    raise e
+                    try:
+                        await maybe_coroutine(self.cog_unload)
+                    finally:
+                        raise e
 
         # check if we're overriding the default
         if cls.bot_check is not Cog.bot_check:
