@@ -24,7 +24,6 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 from typing import List, Literal, Optional, TYPE_CHECKING, Tuple, TypeVar, Callable, Union
-from contextvars import ContextVar
 import inspect
 import os
 
@@ -54,8 +53,6 @@ if TYPE_CHECKING:
 
 V = TypeVar('V', bound='View', covariant=True)
 
-selected_values: ContextVar[Optional[List[str]]] = ContextVar('selected_values', default=None)
-
 
 class Select(Item[V]):
     """Represents a UI select menu.
@@ -111,6 +108,7 @@ class Select(Item[V]):
         row: Optional[int] = None,
     ) -> None:
         super().__init__()
+        self._selected_values: List[str] = []
         self._provided_custom_id = custom_id is not MISSING
         custom_id = os.urandom(16).hex() if custom_id is MISSING else custom_id
         if not isinstance(custom_id, str):
@@ -138,7 +136,6 @@ class Select(Item[V]):
             raise TypeError('custom_id must be None or str')
 
         self._underlying.custom_id = value
-        self._provided_custom_id = value is not None
 
     @property
     def placeholder(self) -> Optional[str]:
@@ -262,8 +259,7 @@ class Select(Item[V]):
     @property
     def values(self) -> List[str]:
         """List[:class:`str`]: A list of values that have been selected by the user."""
-        values = selected_values.get()
-        return values if values is not None else []
+        return self._selected_values
 
     @property
     def width(self) -> int:
@@ -276,7 +272,7 @@ class Select(Item[V]):
         self._underlying = component
 
     def _refresh_state(self, data: MessageComponentInteractionData) -> None:
-        selected_values.set(data.get('values', []))
+        self._selected_values = data.get('values', [])
 
     @classmethod
     def from_component(cls, component: SelectMenu) -> Self:
